@@ -1172,7 +1172,7 @@ def kpppk_pctoindex(c):
     return ppp48_slice * BLOCK_A + wk * BLOCK_B + bk
 
 
-Endgamekey = collections.namedtuple("Endgamekey", ["maxindex", "slice_n", "pctoi"])
+Endgamekey = collections.namedtuple("Endgamekey", "maxindex slice_n pctoi")
 
 EGKEY = {
     "kqk": Endgamekey(MAX_KXK, 1, kxk_pctoindex),
@@ -1517,7 +1517,7 @@ class Request(object):
         self.white_piece_squares = None
 
 
-Zipinfo = collections.namedtuple("Zipinfo", ["extraoffset", "totalblocks", "blockindex"])
+Zipinfo = collections.namedtuple("Zipinfo", "extraoffset totalblocks blockindex")
 
 
 class PythonTablebases(object):
@@ -1547,11 +1547,11 @@ class PythonTablebases(object):
         """
         Probes for depth to mate information.
 
-        The absolute value is the number of half moves until forced mate
+        The absolute value is the number of half-moves until forced mate
         (or ``0`` in drawn positions). The value is positive if the
         side to move is winning, otherwise it is negative.
 
-        In the example position white to move will get mated in 10 half moves:
+        In the example position white to move will get mated in 10 half-moves:
 
         >>> import chess
         >>> import chess.gaviota
